@@ -1,12 +1,18 @@
 pub mod tree;
-
-#[cfg(feature = "text")]
-pub mod text;
 pub mod flexbox;
 pub mod geometry;
 pub mod bitmap;
 pub mod application;
 
+#[cfg(feature = "text")]
+pub mod text;
+
+#[cfg(feature = "xml")]
+pub mod xml;
+
+#[cfg(feature = "png")]
+pub mod png;
+
 pub use application::Application;
 
 pub use geometry::Point;
